@@ -2,10 +2,21 @@ import unittest
 import _cubrid
 from _cubrid import *
 import time
+from xml.dom import minidom
 
 class DatabaseTest(unittest.TestCase):
     driver = _cubrid
-    connect_args = ('CUBRID:test-db-server:33000:demodb:::', 'public', '')
+    
+    xmlt = minidom.parse('python_config.xml')
+    ips = xmlt.childNodes[0].getElementsByTagName('ip')
+    ip = ips[0].childNodes[0].toxml()
+    ports = xmlt.childNodes[0].getElementsByTagName('port')
+    port = ports[0].childNodes[0].toxml()
+    dbnames = xmlt.childNodes[0].getElementsByTagName('dbname')
+    dbname = dbnames[0].childNodes[0].toxml()
+    conStr = "CUBRID:"+ip+":"+port+":"+dbname+":::"
+    
+    connect_args = (conStr, 'dba', '')
     connect_kw_args = {}
 
     def setUp(self):
@@ -160,13 +171,13 @@ class DatabaseTest(unittest.TestCase):
     def test_autocommit(self):
         con = self._connect()
         try:
-            self.assertEqual(con.autocommit, 'TRUE',
-                    'connection.autocommit default is FALSE')
-            con.set_autocommit('ON')
-            self.assertEqual(con.autocommit, 'TRUE',
+            self.assertEqual(con.autocommit, True,
+                    'connection.autocommit default is True')
+            con.set_autocommit(True)
+            self.assertEqual(con.autocommit, True,
                     'connection.autocommit should TURE after set on')
-            con.set_autocommit('OFF')
-            self.assertEqual(con.autocommit, 'FALSE',
+            con.set_autocommit(False)
+            self.assertEqual(con.autocommit, False,
                     'connection.autocommit should TURE after set on')
         finally:
             con.close()
@@ -200,7 +211,7 @@ class DatabaseTest(unittest.TestCase):
             cur.prepare("insert into test_cubrid(name) values ('Blair')")
             cur.execute()
             insert_id = con.insert_id()
-            self.assertEqual(insert_id, '1000000000000',
+            self.assertEqual(insert_id, 1000000000000,
                     'connection.insert_id() get incorrect result')
         finally:
             cur.close()
@@ -463,5 +474,8 @@ def suite():
 if __name__ == '__main__':
     #unittest.main(defaultTest = 'suite')
     #unittest.main()
+    log_file = 'test_cubrid.result'
+    f = open(log_file, "w")
     suite = unittest.TestLoader().loadTestsFromTestCase(DatabaseTest)
-    unittest.TextTestRunner(verbosity=2).run(suite)
+    unittest.TextTestRunner(verbosity=2, stream=f).run(suite)
+    f.close()
